==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/GetThroughputPoolPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.GetThroughputPoolPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property throughputPoolName Cosmos DB Throughput Pool name.
 */
public data class GetThroughputPoolPlainArgs(
    public val resourceGroupName: String,
    public val throughputPoolName: String,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.GetThroughputPoolPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.GetThroughputPoolPlainArgs =
        com.pulumi.azurenative.documentdb.inputs.GetThroughputPoolPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .throughputPoolName(throughputPoolName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetThroughputPoolPlainArgs].
 */
@PulumiTagMarker
public class GetThroughputPoolPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var throughputPoolName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("cbmclrmlknghrqdm")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Cosmos DB Throughput Pool name.
     */
    @JvmName("fdrbkmhvomrgxhqr")
    public suspend fun throughputPoolName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.throughputPoolName = mapped
    }

    internal fun build(): GetThroughputPoolPlainArgs = GetThroughputPoolPlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        throughputPoolName = throughputPoolName ?: throw PulumiNullFieldException("throughputPoolName"),
    )
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/GetThroughputPoolPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.GetThroughputPoolPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property throughputPoolName Cosmos DB Throughput Pool name.
 */
public data class GetThroughputPoolPlainArgs(
    public val resourceGroupName: String,
    public val throughputPoolName: String,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.GetThroughputPoolPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.GetThroughputPoolPlainArgs =
        com.pulumi.azurenative.documentdb.inputs.GetThroughputPoolPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .throughputPoolName(throughputPoolName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetThroughputPoolPlainArgs].
 */
@PulumiTagMarker
public class GetThroughputPoolPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var throughputPoolName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("foncvbbqyogubpmp")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Cosmos DB Throughput Pool name.
     */
    @JvmName("dtnnkackrriushax")
    public suspend fun throughputPoolName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.throughputPoolName = mapped
    }

    internal fun build(): GetThroughputPoolPlainArgs = GetThroughputPoolPlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        throughputPoolName = throughputPoolName ?: throw PulumiNullFieldException("throughputPoolName"),
    )
}
